==> webkitgtk-2.8.1.tar.xz: webkitgtk-2.8.1/Source/JavaScriptCore/dfg/DFGDesiredIdentifiers.h <==
/*
 * Copyright (C) 2013, 2014 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 */

#ifndef DFGDesiredIdentifiers_h
#define DFGDesiredIdentifiers_h

#if ENABLE(DFG_JIT)

#include "Identifier.h"

namespace JSC {

class CodeBlock;

namespace DFG {

class CommonData;

class DesiredIdentifiers {
public:
    DesiredIdentifiers();
    DesiredIdentifiers(CodeBlock*);
    ~DesiredIdentifiers();
    
    unsigned numberOfIdentifiers();
    void addLazily(AtomicStringImpl*);
    
    AtomicStringImpl* at(unsigned index) const;
    
    AtomicStringImpl* operator[](unsigned index) const { return at(index); }
    
    void reallyAdd(VM&, CommonData*);
    
private:
    CodeBlock* m_codeBlock;
    Vector<AtomicStringImpl*> m_addedIdentifiers;
};

} } // namespace JSC::DFG

#endif // ENABLE(DFG_JIT)

#endif // DFGDesiredIdentifiers_h

==> webkitgtk-2.27.3.tar.xz: webkitgtk-2.27.3/Source/JavaScriptCore/dfg/DFGDesiredIdentifiers.h <==
/*
 * Copyright (C) 2013-2015 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 */

#pragma once

#if ENABLE(DFG_JIT)

#include <wtf/HashMap.h>
#include <wtf/Variant.h>
#include <wtf/text/UniquedStringImpl.h>

namespace JSC {

class CodeBlock;
class VM;

namespace DFG {

class CommonData;

class DesiredIdentifiers {
public:
    DesiredIdentifiers();
    DesiredIdentifiers(CodeBlock*);
    ~DesiredIdentifiers();
    
    unsigned numberOfIdentifiers();
    unsigned ensure(UniquedStringImpl*);
    unsigned ensure(Box<Identifier>);
    
    UniquedStringImpl* at(unsigned index) const;
    
    UniquedStringImpl* operator[](unsigned index) const { return at(index); }
    
    void reallyAdd(VM&, CommonData*);
    
private:
    void processCodeBlockIdentifiersIfNeeded();

    CodeBlock* m_codeBlock;
    Vector<Variant<UniquedStringImpl*, Box<Identifier>>> m_addedIdentifiers;
    HashMap<UniquedStringImpl*, unsigned> m_identifierNumberForName;
    bool m_didProcessIdentifiers;
};

} } // namespace JSC::DFG

#endif // ENABLE(DFG_JIT)
